
function [t, w]=rk4back(f,t0, tf, N, init2,U,YY,Constant)
%function rk4back() approximates the solutions of systems of 
%differential equations
%with input ode function f and t in the interval [a; b] and the initial 
%conditions are in the m-dimensional vector alpha
%as with function rk4back(), the inputs are the endpoints a and b, the
%number of subdivisions N in the interval [a; b], and the initial
h = -(tf-t0)/N;     %the step size
t(N) = tf;
w(:,N) = init2;     %initial conditions

for i = N:-1:1
   uu = U(i,:);
   yy = YY(:,i);
   k1 = h*f(t(i),w(:,i),uu,yy,Constant);
   k2 = h*f(t(i)+h/2, w(:,i)+0.5*k1,uu,yy,Constant);
   k3 = h*f(t(i)+h/2, w(:,i)+0.5*k2,uu,yy,Constant ); 
   k4 = h*f(t(i)+h, w(:,i)+k3,uu,yy,Constant);
  if i>1
   w(:,i-1) = w(:,i) + (k1 + 2*k2 + 2*k3 + k4)/6;
   t(i-1) = tf + i*h; 
  else
   ww = w(:,i) + (k1 + 2*k2 + 2*k3 + k4)/6;
   tt = tf + i*h;   
  end
end
w = [ww w];
t = [tt t];

