function [t, w]=rk4foward_edit(f,t0, tf, N, init,U,constant)
%function rk4() approximates the solutions of systems of 
%differential equations
%with input ode function f and t in the interval [a; b] and the initial 
%conditions are in the m-dimensional vector alpha
%as with function rk4(), the inputs are the endpoints a and b, the
%number of subdivisions N in the interval [a; b], and the initial
h      = (tf-t0)/N;        %the step size
t(1)   = t0;
w(:,1) = init;            %initial conditions
for i = 1:N
   uu = 0.5*(U(i,:)+U(i+1,:));
   k1 = h*f(t(i),w(:,i),uu,constant);
   k2 = h*f(t(i)+h/2, w(:,i)+0.5*k1,uu,constant);
   k3 = h*f(t(i)+h/2, w(:,i)+0.5*k2,uu,constant); 
   k4 = h*f(t(i)+h, w(:,i)+k3,U(i+1,:),constant);
   w(:,i+1) = w(:,i) + (k1 + 2*k2 + 2*k3 + k4)/6;
  
   t(i+1)   = t0 + i*h;
  
end